==> igniteui-angular-charts-16.0.0.tgz: package/esm5/lib/MassIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MassIndexIndicatorStrategy } from "./MassIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var MassIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MassIndexIndicator, _super);
    function MassIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MassIndexIndicator.prototype.get_ul = function () {
        return new MassIndexIndicatorStrategy();
    };
    Object.defineProperty(MassIndexIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.prototype.get_uy = function () {
        return MassIndexIndicator.$;
    };
    Object.defineProperty(MassIndexIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.$t = markType(MassIndexIndicator, 'MassIndexIndicator', StrategyBasedIndicator.$);
    return MassIndexIndicator;
}(StrategyBasedIndicator));
export { MassIndexIndicator };

==> igniteui-angular-charts-17.2.1.tgz: package/esm5/lib/MassIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MassIndexIndicatorStrategy } from "./MassIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var MassIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MassIndexIndicator, _super);
    function MassIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MassIndexIndicator.prototype.bg = function () {
        return new MassIndexIndicator();
    };
    MassIndexIndicator.prototype.get_yz = function () {
        return new MassIndexIndicatorStrategy();
    };
    Object.defineProperty(MassIndexIndicator.prototype, "yz", {
        get: function () {
            return this.get_yz();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.prototype.get_zc = function () {
        return MassIndexIndicator.$;
    };
    Object.defineProperty(MassIndexIndicator.prototype, "zc", {
        get: function () {
            return this.get_zc();
        },
        enumerable: false,
        configurable: true
    });
    MassIndexIndicator.$t = markType(MassIndexIndicator, 'MassIndexIndicator', StrategyBasedIndicator.$);
    return MassIndexIndicator;
}(StrategyBasedIndicator));
export { MassIndexIndicator };
